@@ -16,6 +16,10 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
+#ifdef _WIN32
+#include <windows.h>
+#endif
+
 #include "worldscene.h"
 #include "worldscene.moc"
 
